@@ -1,5 +1,6 @@
 from fwiffos.core import version
 from fwiffos.cli.sudo import LetUs
+from fwiffos.cli.admin import AdminCLI
 from fwiffos.read.twitter import Twitter
 
 class Calculator(object):
@@ -24,6 +25,7 @@ class Commands(object):
         calc = Calculator()
         sudo = LetUs()
         twitter = Twitter()
+        admin = AdminCLI()
         self._version = version
         self.__commands = {
             'ls': fs.ls,
@@ -32,6 +34,7 @@ class Commands(object):
             'sudo': sudo.letus,
             'letus': sudo.letus,
             'read': twitter.tweet,
+            'admin': admin.list,
         }
 
     def exec(self):
