@@ -2,8 +2,8 @@
 
 import ldap
 
-ARCHIVEOS_DOMAIN=scupper.club
-ARCHIVEOS_BASEDN=dc=scupper,dc=club
+ARCHIVEOS_DOMAIN='scupper.club'
+ARCHIVEOS_BASEDN='dc=scupper,dc=club'
 
 def list_admins():
     ldap_url = 'ldap://' + ARCHIVEOS_ROOT
